==> FreePastry-1.4.1_01_20050914-source.zip: pastry-1.4.1_01_20050914/src/rice/p2p/glacier/v2/messaging/GlacierSyncMessage.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.p2p.glacier.v2.messaging;

import rice.*;
import rice.p2p.commonapi.*;
import rice.p2p.glacier.*;
import rice.p2p.glacier.v2.BloomFilter;

/**
 * DESCRIBE THE CLASS
 *
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author jeffh
 */
public class GlacierSyncMessage extends GlacierMessage {
  /**
   * DESCRIBE THE FIELD
   */
  protected IdRange range;
  /**
   * DESCRIBE THE FIELD
   */
  protected int offsetFID;
  /**
   * DESCRIBE THE FIELD
   */
  protected BloomFilter BloomFilter;

  /**
   * Constructor for GlacierSyncMessage.
   *
   * @param uid DESCRIBE THE PARAMETER
   * @param range DESCRIBE THE PARAMETER
   * @param offsetFID DESCRIBE THE PARAMETER
   * @param BloomFilter DESCRIBE THE PARAMETER
   * @param source DESCRIBE THE PARAMETER
   * @param dest DESCRIBE THE PARAMETER
   * @param tag DESCRIBE THE PARAMETER
   */
  public GlacierSyncMessage(int uid, IdRange range, int offsetFID, BloomFilter BloomFilter, NodeHandle source, Id dest, char tag) {
    super(uid, source, dest, false, tag);

    this.range = range;
    this.offsetFID = offsetFID;
    this.BloomFilter = BloomFilter;
  }

  /**
   * Gets the OffsetFID attribute of the GlacierSyncMessage object
   *
   * @return The OffsetFID value
   */
  public int getOffsetFID() {
    return offsetFID;
  }

  /**
   * Gets the Range attribute of the GlacierSyncMessage object
   *
   * @return The Range value
   */
  public IdRange getRange() {
    return range;
  }

  /**
   * Gets the BloomFilter attribute of the GlacierSyncMessage object
   *
   * @return The BloomFilter value
   */
  public BloomFilter getBloomFilter() {
    return BloomFilter;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @return DESCRIBE THE RETURN VALUE
   */
  public String toString() {
    return "[GlacierSync for range " + range + ", offset " + offsetFID + "]";
  }
}

==> FreePastry-2.0b2_20060718-source.zip: pastry-2.0b2_20060718/src/rice/p2p/glacier/v2/messaging/GlacierSyncMessage.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.p2p.glacier.v2.messaging;

import java.io.IOException;

import rice.*;
import rice.p2p.commonapi.*;
import rice.p2p.commonapi.rawserialization.*;
import rice.p2p.glacier.*;
import rice.p2p.glacier.v2.BloomFilter;

/**
 * DESCRIBE THE CLASS
 *
 * @version $Id: pretty.settings 2305 2005-03-11 20:22:33Z jeffh $
 * @author jeffh
 */
public class GlacierSyncMessage extends GlacierMessage {

  /**
   * DESCRIBE THE FIELD
   */
  protected IdRange range;
  /**
   * DESCRIBE THE FIELD
   */
  protected int offsetFID;
  /**
   * DESCRIBE THE FIELD
   */
  protected BloomFilter BloomFilter;
  /**
   * DESCRIBE THE FIELD
   */
  public final static short TYPE = 14;

  /**
   * Constructor for GlacierSyncMessage.
   *
   * @param uid DESCRIBE THE PARAMETER
   * @param range DESCRIBE THE PARAMETER
   * @param offsetFID DESCRIBE THE PARAMETER
   * @param BloomFilter DESCRIBE THE PARAMETER
   * @param source DESCRIBE THE PARAMETER
   * @param dest DESCRIBE THE PARAMETER
   * @param tag DESCRIBE THE PARAMETER
   */
  public GlacierSyncMessage(int uid, IdRange range, int offsetFID, BloomFilter BloomFilter, NodeHandle source, Id dest, char tag) {
    super(uid, source, dest, false, tag);

    this.range = range;
    this.offsetFID = offsetFID;
    this.BloomFilter = BloomFilter;
  }

  /**
   * Constructor for GlacierSyncMessage.
   *
   * @param buf DESCRIBE THE PARAMETER
   * @param endpoint DESCRIBE THE PARAMETER
   * @exception IOException DESCRIBE THE EXCEPTION
   */
  private GlacierSyncMessage(InputBuffer buf, Endpoint endpoint) throws IOException {
    super(buf, endpoint);
    offsetFID = buf.readInt();
    range = endpoint.readIdRange(buf);
    BloomFilter = new BloomFilter(buf);
  }

  /**
   * Gets the OffsetFID attribute of the GlacierSyncMessage object
   *
   * @return The OffsetFID value
   */
  public int getOffsetFID() {
    return offsetFID;
  }

  /**
   * Gets the Range attribute of the GlacierSyncMessage object
   *
   * @return The Range value
   */
  public IdRange getRange() {
    return range;
  }

  /**
   * Gets the BloomFilter attribute of the GlacierSyncMessage object
   *
   * @return The BloomFilter value
   */
  public BloomFilter getBloomFilter() {
    return BloomFilter;
  }

  /**
   * Raw Serialization **************************************
   *
   * @return The Type value
   */
  public short getType() {
    return TYPE;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @return DESCRIBE THE RETURN VALUE
   */
  public String toString() {
    return "[GlacierSync for range " + range + ", offset " + offsetFID + "]";
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @param buf DESCRIBE THE PARAMETER
   * @exception IOException DESCRIBE THE EXCEPTION
   */
  public void serialize(OutputBuffer buf) throws IOException {
    buf.writeByte((byte) 0);
    // version
    super.serialize(buf);
    buf.writeInt(offsetFID);
    range.serialize(buf);
    BloomFilter.serialize(buf);
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @param buf DESCRIBE THE PARAMETER
   * @param endpoint DESCRIBE THE PARAMETER
   * @return DESCRIBE THE RETURN VALUE
   * @exception IOException DESCRIBE THE EXCEPTION
   */
  public static GlacierSyncMessage build(InputBuffer buf, Endpoint endpoint) throws IOException {
    byte version = buf.readByte();
    switch (version) {
      case 0:
        return new GlacierSyncMessage(buf, endpoint);
      default:
        throw new IOException("Unknown Version: " + version);
    }
  }
}
